==> nextcloud-app-mail-5.5.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/sq.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "E rëndësishme",
    "Work" : "Punë",
    "Personal" : "Personale",
    "Later" : "Më vonë",
    "Mail" : "Posta",
    "Connecting" : "Duke u lidhur",
    "Save" : "Ruaj",
    "Connect" : "Lidhu",
    "Password required" : "Kërkohet fjalëkalimi",
    "Name" : "Emri",
    "Mail address" : "Adresa e postës elektronike",
    "Password" : "Fjalëkalimi",
    "IMAP Host" : "Strehë IMAP",
    "None" : "Asnjë",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Përdorues IMAP",
    "IMAP Password" : "Fjalëkalimi i IMAP",
    "SMTP Host" : "Streha e SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Përdoruesi i SMTP",
    "SMTP Password" : "Fjalëkalimi SMTP",
    "Aliases" : "Emërtimet",
    "Signature" : "Nënshkrimi",
    "Go back" : "Shko prapa",
    "Cancel" : "Anullo",
    "Accounts" : "Llogari",
    "Add mail account" : "Shto llogarinë e postës elektronike",
    "General" : "Të përgjithshme",
    "Register" : "Regjistrohu",
    "About" : "Rreth",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Newer message" : "Mesazhe më të reja",
    "Older message" : "Mesazhe më të vjetra",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle i pa lexuar",
    "Archive" : "Arkiva",
    "Delete" : "Fshij",
    "Search" : "Kërko",
    "Send" : "Dërgo",
    "Refresh" : "Rifresko",
    "Ok" : "Në rregull",
    "Select account" : "Përzgjidhni llogari",
    "Subject" : "Temë",
    "Upload attachment" : "Ngarko bashkëngjitje",
    "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
    "Choose" : "Zgjidhni",
    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
    "Confirm" : "Konfirmo",
    "Unfavorite" : "Jo i/e preferuar",
    "Favorite" : "I/E Preferuar",
    "Read" : "Lexoni",
    "Edit tags" : "Përpunoni etiketa",
    "More actions" : "Më tepër veprime ",
    "Back" : "Prapa",
    "Mark as unread" : "Shënoje si të palexuar",
    "Mark as read" : "Shënoje si të lexuar",
    "All day" : "Gjithë ditën",
    "Attendees" : "Pjesëmarrës",
    "Description" : "Përshkrim",
    "Create" : "Krijo",
    "Select" : "Zgjidhni",
    "Comment" : "Koment",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "Remove" : "Hiq",
    "email" : "postë elektronike",
    "Today" : "Sot",
    "Other" : "Tjetër",
    "Forward" : "Përpara",
    "Translate" : "Përkthe",
    "Unnamed" : "E paemër",
    "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
    "Import into calendar" : "Importo në kalendar",
    "Download attachment" : "Shkarko bashkëlidhjen",
    "Save to Files" : "Ruaje te Skedarët",
    "Save all to Files" : "Ruaji të gjitha te Dosjet",
    "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
    "Move" : "Zhvendos",
    "Remove account" : "Fshij llogarinë",
    "Folder name" : "Emër dosjeje",
    "Saving" : "Duke u ruajtur!",
    "Show all folders" : "Shfaqi krejt dosjet",
    "Collapse folders" : "Tkurri dosjet",
    "Delete folder" : "Fshije dosjen",
    "Mark all as read" : "Shënoji krejt si të lexuar",
    "Rename" : "Riemërtoje",
    "Clear cache" : "Pastroje fshehtinën",
    "New message" : "Mesazh i ri",
    "Reply" : "Përgjigju",
    "Retry" : "Riprovoni",
    "Message" : "Mesazh",
    "Copy to clipboard" : "Kopjo në dërrasë ",
    "Add" : "Shto",
    "Clear" : "Pastro",
    "Close" : "Mbylleni",
    "Date" : "Data",
    "Tags" : "Etiketat",
    "Select tags" : "Përzgjidh etiketat",
    "Custom" : "E përshtatur",
    "Delete tag" : "Fshi etiketën",
    "Tag already exists" : "Etiketa ekziston",
    "Add tag" : "Shto etiketim",
    "Recipient" : "Marrës",
    "Help" : "Ndihmë",
    "matches" : "përputhje",
    "Actions" : "Veprimet",
    "Priority" : "Përparësi",
    "delete" : "fshi",
    "Edit" : "Përpuno",
    "Reset" : "Rivendos",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "User" : "Përdorues",
    "Host" : "Strehë",
    "Port" : "Porta",
    "Valid until" : "E vlefshme deri më",
    "Certificate" : "Çertifikata",
    "Submit" : "Dërgo",
    "Group" : "Grup",
    "Shared" : "Ndarë",
    "Shares" : "Shpërndarje",
    "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
    "All" : "Të gjithë",
    "Drafts" : "Skica",
    "Favorites" : "Favorites",
    "All inboxes" : "Krejt kutitë e postës",
    "Inbox" : "Inbox",
    "Junk" : "Të pavlera",
    "Sent" : "Të dërguar",
    "Trash" : "Hedhurina",
    "{from}\n{subject}" : "{nga}\n{subjekt}",
    "Message sent" : "Mesazhi u dërgua",
    "Could not load {tag}{name}{endtag}" : "Nuk mund të ngarkohej {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Pati një problem me ngarkimin e {tag}{name}{endtag}",
    "Error loading message" : "Gabim në ngarkimin e kartelës",
    "Forwarding to %s" : "Ridrejto te %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
    "Redirect" : "Ridrejtoje",
    "The link leads to %s" : "Lidhja shpie te %s",
    "Continue to %s" : "Vazhdo te %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.5.11-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/sq.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "E rëndësishme",
    "Work" : "Punë",
    "Personal" : "Personale",
    "Later" : "Më vonë",
    "Mail" : "Posta",
    "Connecting" : "Duke u lidhur",
    "Save" : "Ruaj",
    "Connect" : "Lidhu",
    "Password required" : "Kërkohet fjalëkalimi",
    "Name" : "Emri",
    "Mail address" : "Adresa e postës elektronike",
    "Password" : "Fjalëkalimi",
    "IMAP Host" : "Strehë IMAP",
    "None" : "Asnjë",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Përdorues IMAP",
    "IMAP Password" : "Fjalëkalimi i IMAP",
    "SMTP Host" : "Streha e SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Përdoruesi i SMTP",
    "SMTP Password" : "Fjalëkalimi SMTP",
    "Aliases" : "Emërtimet",
    "Signature" : "Nënshkrimi",
    "Go back" : "Shko prapa",
    "Cancel" : "Anullo",
    "General" : "Të përgjithshme",
    "Add mail account" : "Shto llogarinë e postës elektronike",
    "Newest first" : "Më i riu i pari",
    "Oldest first" : "Më i vjetri i pari",
    "Register" : "Regjistrohu",
    "Security" : "Siguria",
    "Manage certificates" : "Menaxhoni certifikatat",
    "About" : "Rreth",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Newer message" : "Mesazhe më të reja",
    "Older message" : "Mesazhe më të vjetra",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle i pa lexuar",
    "Archive" : "Arkiva",
    "Delete" : "Fshij",
    "Search" : "Kërko",
    "Send" : "Dërgo",
    "Refresh" : "Rifresko",
    "Ok" : "Në rregull",
    "Select account" : "Përzgjidhni llogari",
    "Subject" : "Temë",
    "Upload attachment" : "Ngarko bashkëngjitje",
    "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
    "Choose" : "Zgjidhni",
    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
    "Confirm" : "Konfirmo",
    "Unfavorite" : "Jo i/e preferuar",
    "Favorite" : "I/E Preferuar",
    "Read" : "Lexoni",
    "Edit tags" : "Përpunoni etiketa",
    "More actions" : "Më tepër veprime ",
    "Back" : "Prapa",
    "Mark as unread" : "Shënoje si të palexuar",
    "Mark as read" : "Shënoje si të lexuar",
    "All day" : "Gjithë ditën",
    "Attendees" : "Pjesëmarrës",
    "Description" : "Përshkrim",
    "Create" : "Krijo",
    "Select" : "Zgjidhni",
    "Comment" : "Koment",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "Remove" : "Hiq",
    "email" : "postë elektronike",
    "Today" : "Sot",
    "Other" : "Tjetër",
    "Forward" : "Përpara",
    "Translate" : "Përkthe",
    "Unnamed" : "E paemër",
    "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
    "Import into calendar" : "Importo në kalendar",
    "Download attachment" : "Shkarko bashkëlidhjen",
    "Save to Files" : "Ruaje te Skedarët",
    "Save all to Files" : "Ruaji të gjitha te Dosjet",
    "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
    "Move" : "Zhvendos",
    "Remove account" : "Fshij llogarinë",
    "Folder name" : "Emër dosjeje",
    "Saving" : "Duke u ruajtur!",
    "Show all folders" : "Shfaqi krejt dosjet",
    "Collapse folders" : "Tkurri dosjet",
    "Delete folder" : "Fshije dosjen",
    "Mark all as read" : "Shënoji krejt si të lexuar",
    "Rename" : "Riemërtoje",
    "Clear cache" : "Pastroje fshehtinën",
    "New message" : "Mesazh i ri",
    "Reply" : "Përgjigju",
    "Retry" : "Riprovoni",
    "Message" : "Mesazh",
    "Copy to clipboard" : "Kopjo në dërrasë ",
    "Add" : "Shto",
    "Clear" : "Pastro",
    "Close" : "Mbylleni",
    "Date" : "Data",
    "Tags" : "Etiketat",
    "Select tags" : "Përzgjidh etiketat",
    "Custom" : "E përshtatur",
    "Delete tag" : "Fshi etiketën",
    "Tag already exists" : "Etiketa ekziston",
    "Add tag" : "Shto etiketim",
    "Recipient" : "Marrës",
    "Help" : "Ndihmë",
    "matches" : "përputhje",
    "Actions" : "Veprimet",
    "Priority" : "Përparësi",
    "delete" : "fshi",
    "Edit" : "Përpuno",
    "Reset" : "Rivendos",
    "Client ID" : "ID klienti",
    "Client secret" : "E fshehtë klienti",
    "User" : "Përdorues",
    "Host" : "Strehë",
    "Port" : "Porta",
    "Valid until" : "E vlefshme deri më",
    "Certificate" : "Çertifikata",
    "Submit" : "Dërgo",
    "Group" : "Grup",
    "Shared" : "Ndarë",
    "Shares" : "Shpërndarje",
    "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
    "All" : "Të gjithë",
    "Drafts" : "Skica",
    "Favorites" : "Favorites",
    "All inboxes" : "Krejt kutitë e postës",
    "Inbox" : "Inbox",
    "Junk" : "Të pavlera",
    "Sent" : "Të dërguar",
    "Trash" : "Hedhurina",
    "{from}\n{subject}" : "{nga}\n{subjekt}",
    "Message sent" : "Mesazhi u dërgua",
    "Could not load {tag}{name}{endtag}" : "Nuk mund të ngarkohej {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Pati një problem me ngarkimin e {tag}{name}{endtag}",
    "Error loading message" : "Gabim në ngarkimin e kartelës",
    "Forwarding to %s" : "Ridrejto te %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
    "Redirect" : "Ridrejtoje",
    "The link leads to %s" : "Lidhja shpie te %s",
    "Continue to %s" : "Vazhdo te %s",
    "Accounts" : "Llogari"
},
"nplurals=2; plural=(n != 1);");
